@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2000-2017 Greg Sabino Mullane and others: see the Changes file
+    Copyright (c) 2000-2019 Greg Sabino Mullane and others: see the Changes file
 	Portions Copyright (c) 1997-2000 Edmund Mergl
 	Portions Copyright (c) 1994-1997 Tim Bunce
 	
@@ -23,7 +23,7 @@ struct imp_dbh_st {
 	int     copystate;         /* 0=none PGRES_COPY_IN PGRES_COPY_OUT */
 	bool    copybinary;        /* whether the copy is in binary format */
 	int     pg_errorlevel;     /* PQsetErrorVerbosity. Set by user, defaults to 1 */
-	int     server_prepare;    /* do we want to use PQexecPrepared? 0=no 1=yes 2=smart. Can be changed by user */
+	bool    server_prepare;    /* do we want to use PQexecPrepared? Can be changed by user */
 	int     switch_prepared;   /* how many executes until we switch to PQexecPrepared */
 	int     async_status;      /* 0=no async 1=async started -1=async has been cancelled */
 
@@ -88,7 +88,7 @@ typedef enum
 struct imp_sth_st {
 	dbih_stc_t com;          /* MUST be first element in structure */
 
-	int    server_prepare;    /* inherited from dbh. 3 states: 0=no 1=yes 2=smart */
+	bool   server_prepare;    /* inherited from dbh */
 	int    switch_prepared;   /* inherited from dbh */
     int    number_iterations; /* how many times has the statement been executed? Used by switch_prepared */
 	PGPlaceholderType placeholder_type;  /* which style is being used 1=? 2=$1 3=:foo */
@@ -117,7 +117,6 @@ struct imp_sth_st {
 
 	bool   prepare_now;      /* prepare this statement right away, even if it has placeholders */
 	bool   prepared_by_us;   /* false if {prepare_name} set directly */
-	bool   onetime;          /* this statement is guaranteed not to be run again - so don't use SSP */
 	bool   direct;           /* allow bypassing of the statement parsing */
 	bool   is_dml;           /* is this SELECT/INSERT/UPDATE/DELETE? */
 	bool   has_binary;       /* does it have one or more binary placeholders? */
