@@ -165,7 +165,6 @@ version: $version
 					}
 
 					warn "Restarting test database $testdsn at $testdir\n";
-					my $option = '';
 					if ($^O !~ /Win32/) {
 						my $sockdir = "$testdir/data/socket";
 						if (! -e $sockdir) {
@@ -176,12 +175,8 @@ version: $version
 								}
 							}
 						}
-						$option = q{-o '-k socket'};
-						if ($version <= 8.0) {
-							$option = q{-o '-k dbdpg_test_database/data/socket'};
-						}
 					}
-					my $COM = qq{$pg_ctl $option -l $testdir/dbdpg_test.logfile -D $testdir/data start};
+					my $COM = qq{$pg_ctl -o '-k $testdir/data/socket' -l $testdir/dbdpg_test.logfile -D $testdir/data start};
 					if ($su) {
 						$COM = qq{su -m $su -c "$COM"};
 						chdir $testdir;
@@ -285,7 +280,9 @@ version: $version
 		$helpconnect = 16;
 
 		## Use the initdb found by App::Info
-		$initdb = $ENV{DBDPG_INITDB} || $ENV{PGINITDB} || '';
+        if (! length $initdb or $initdb eq 'default') {
+            $initdb = $ENV{DBDPG_INITDB} || $ENV{PGINITDB} || '';
+        }
 		if (!$initdb or ! -e $initdb) {
 			$initdb = 'initdb';
 		}
@@ -318,7 +315,7 @@ version: $version
 		elsif ($info =~ /(\d+\.\d+)/) {
 			$version = $1;
 		}
-		elsif ($info =~ /(\d+)(?:devel|beta)/) { ## Can be 10devel
+		elsif ($info =~ /(\d+)(?:devel|beta|rc|alpha)/) { ## Can be 10devel
 			$version = $1;
 		}
 		else {
@@ -334,7 +331,7 @@ version: $version
 			$info = qx{$pg_ctl --help 2>&1};
 		};
 		last GETHANDLE if $@; ## Fail - pg_ctl bad
-		if (!defined $info or ($info !~ /\@postgresql\.org/ and $info !~ /run as root/)) {
+		if (!defined $info or ($info !~ /\@[a-z.-]*?postgresql\.org/ and $info !~ /run as root/)) {
 			$@ = defined $initdb ? "Bad pg_ctl output: $info" : 'Bad pg_ctl output';
 			last GETHANDLE; ## Fail - pg_ctl bad
 		}
@@ -421,6 +418,11 @@ version: $version
 			last GETHANDLE; ## Fail - bad output
 		}
 
+		## Which user do we connect as?
+		if (!$su and $info =~ /owned by user "(.+?)"/) {
+			$testuser = $1;
+		}
+
 		## Attempt to boost the system oids above an int for certain testing
 		(my $resetxlog = $initdb) =~ s/initdb/pg_resetxlog/;
 		if ($version >= 10) {
@@ -438,19 +440,16 @@ version: $version
 			}
 		}
 
-		## Which user do we connect as?
-		if (!$su and $info =~ /owned by user "(.+?)"/) {
-			$testuser = $1;
-		}
-
 		## Now we need to find an open port to use
 		$testport = 5442;
 		## If we've got netstat available, we'll trust that
 		$info = '';
+        my $evalok = 0;
 		eval {
 			$info = qx{netstat -na 2>&1};
+            $evalok = 1;
 		};
-		if ($@) {
+		if (!$evalok) {
 			warn "netstat call failed, trying port $testport\n";
 		}
 		else {
@@ -500,13 +499,10 @@ version: $version
 			print $cfh "\n\n## DBD::Pg testing parameters\n";
 			print $cfh "port=$testport\n";
 			print $cfh "max_connections=11\n";
-			if ($version >= 8.0) {
-				print $cfh "log_statement = 'all'\n";
-				print $cfh "log_line_prefix = '%m [%p] '\n";
-			}
-			else {
-				print $cfh "silent_mode = true\n";
-			}
+			print $cfh "log_statement = 'all'\n";
+			print $cfh "log_line_prefix = '%m [%p] '\n";
+			print $cfh "log_filename = 'postgres%Y-%m-%d.log'\n";
+			print $cfh "log_rotation_size = 0\n";
 			if ($version == 8.1) {
 				print {$cfh} "redirect_stderr = on\n";
 			}
@@ -515,8 +511,21 @@ version: $version
 				print {$cfh} "logging_collector = on\n";
 			}
 			print $cfh "log_min_messages = 'DEBUG1'\n";
-			print $cfh "log_filename = 'postgres%Y-%m-%d.log'\n";
-			print $cfh "log_rotation_size = 0\n";
+
+			if ($version >= 9.4) {
+				print $cfh "wal_level = logical\n";
+				print $cfh "max_replication_slots = 1\n";
+				print $cfh "max_wal_senders = 1\n";
+
+				open my $hba, '>>', "$testdir/data/pg_hba.conf"
+					or die qq{Could not open "$testdir/data/pg_hba.conf": $!\n};
+
+				print $hba "local\treplication\tall\ttrust\n";
+				print $hba "host\treplication\tall\t127.0.0.1/32\ttrust\n";
+				print $hba "host\treplication\tall\t::1/128\ttrust\n";
+
+				close $hba or die qq{Could not close "$testdir/data/pg_hba.conf": $!\n};
+			}
 
 			print $cfh "listen_addresses='127.0.0.1'\n" if $^O =~ /Win32/;
 			print $cfh "\n";
@@ -524,7 +533,6 @@ version: $version
 
 			## Attempt to start up the test server
 			$info = '';
-			my $option = '';
 			if ($^O !~ /Win32/) {
 				my $sockdir = "$testdir/data/socket";
 				if (! -e $sockdir) {
@@ -535,12 +543,8 @@ version: $version
 						}
 					}
 				}
-				$option = q{-o '-k socket'};
-				if ($version <= 8.0) {
-					$option = q{-o '-k dbdpg_test_database/data/socket'};
-				}
 			}
-			my $COM = qq{$pg_ctl $option -l $testdir/dbdpg_test.logfile -D $testdir/data start};
+			my $COM = qq{$pg_ctl -o '-k $testdir/data/socket' -l $testdir/dbdpg_test.logfile -D $testdir/data start};
 		    $olddir = getcwd;
 			if ($su) {
 				chdir $testdir;
@@ -660,6 +664,7 @@ version: $version
 	if (!$arg->{quickreturn} or 1 != $arg->{quickreturn}) {
 		## non-ASCII parts of the tests assume UTF8
 		$dbh->do('SET client_encoding = utf8');
+		$dbh->{pg_enable_utf8} = -1;
 	}
 
 	if ($arg->{quickreturn}) {
@@ -765,13 +770,20 @@ sub get_test_settings {
 
 	## Find the best candidate for the pg_ctl program
 	my $pg_ctl = 'pg_ctl';
-	if (exists $ENV{DBDPG_INITDB} and -e $ENV{DBDPG_INITDB}) {
+    my $initdb = 'default';
+    if (exists $ENV{POSTGRES_HOME} and -e "$ENV{POSTGRES_HOME}/bin/pg_ctl") {
+        $pg_ctl = "$ENV{POSTGRES_HOME}/bin/pg_ctl";
+        $initdb = "$ENV{POSTGRES_HOME}/bin/initdb";
+    }
+	elsif (exists $ENV{DBDPG_INITDB} and -e $ENV{DBDPG_INITDB}) {
 		($pg_ctl = $ENV{DBDPG_INITDB}) =~ s/initdb/pg_ctl/;
-	} elsif (exists $ENV{PGINITDB} and -e $ENV{PGINITDB}) {
+	}
+    elsif (exists $ENV{PGINITDB} and -e $ENV{PGINITDB}) {
 		($pg_ctl = $ENV{PGINITDB}) =~ s/initdb/pg_ctl/;
 	}
+
 	my ($testdsn, $testuser, $testdir, $error) = ('','','','?');
-	my ($helpconnect, $su, $uid, $initdb, $version) = (0,'','','default',0);
+	my ($helpconnect, $su, $uid, $version) = (0,'','',0);
 	my $inerror = 0;
 	if (-e $helpfile) {
 		open $fh, '<', $helpfile or die qq{Could not open "$helpfile": $!\n};
